The melanom data frame has 205 rows and 7 columns.
It contains data relating to the survival of patients after an operation for
malignant melanoma, collected at Odense University Hospital by K.T.
Drzewiecki.
Usage
melanom
Arguments
encoding
UTF-8
source
P.K. Andersen, Ø{O}. Borgan, R.D. Gill, and N. Keiding (1991),
Statistical Models Based on
Counting Processes, Appendix 1, Springer-Verlag.