Four small experiments with the purpose of estimating the EC50 of a biological dose-response relation.
philionA data frame with 30 observations on the following 3 variables:
experimenta numeric vector; codes 1 through 4 denote the experiment number.
dosea numeric vector, the dose.
responsea numeric vector, the response (counts).
These data were discussed on the R mailing lists, initially suggesting a log-linear Poisson regression, but actually a relation like \(y=y_{\rm max}/(1+(x/\beta)^\alpha)\) is more suitable.