Learn R Programming

ISwR (version 2.0-3)

red.cell.folate: Red cell folate data

Description

The folate data frame has 22 rows and 2 columns. It contains data on red cell folate levels in patients receiving three different methods of ventilation during anesthesia.

Usage

red.cell.folate

Arguments

source

D.G. Altman (1991), Practical Statistics for Medical Research, Table 9.10, Chapman & Hall.

Examples

Run this code
plot(folate~ventilation,data=red.cell.folate)

Run the code above in your browser using DataLab